// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: GPL-3.0-only

#include "filesystem.h"
#include <QDebug>

namespace DiskManager {

FileSystem::FileSystem()
{
    // qDebug() << "Constructing a FileSystem object.";
}
} // namespace DiskManager
